/*  Mutiara motif designer.
	Copyright (C) 2011  Nor Jaidi Tuah

	This file is part of Mutiara.

	Mutiara is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

/**
 * Queue Cairo instructions.
 * Purpose:
 *   - Allow sequential cairo shapes to be computed in parallel. Only the
 *     render method needs to be called in proper sequence.
 * Limitations:
 *   - Only one move_to and this must be called before line_to
 */
public class DeferredCairo {
	Point[] points = {};
	/**
	 * type:
	 *   's' : stroke (default)
	 *   'f' : fill
	 */
	char type = 's';

	public void render (Cairo.Context cr) {
		if (points.length == 0) return;
		cr.move_to (points[0].x, points[0].y);
		for (int i = 1; i < points.length; i++) cr.line_to (points[i].x, points[i].y);
		if (type == 's') cr.stroke ();
		else {cr.fill_preserve (); cr.stroke ();}
		points.length = 0;
	}

	public void move_to (Point p) {
		points += p;
	}

	public void line_to (Point p) {
		if (points.length >= 100000) return;
		points += p;
	}

	public void stroke () {
		type = 's';
	}

	public void fill () {
		type = 'f';
	}

}
// vim: tabstop=4: textwidth=100: autoindent:
